@@ -16,12 +16,21 @@ def get_cache_key(user, key):
     return "%s:permission:%s:%s" % (
         get_cms_setting('CACHE_PREFIX'), user.username, key)
 
+def get_cache_version_key():
+    return "%s:permission:version" % (get_cms_setting('CACHE_PREFIX'),)
+
+def get_cache_version():
+    version = cache.get(get_cache_version_key())
+    if version is None:
+        version = 1
+    return version
+
 
 def get_permission_cache(user, key):
     """
     Helper for reading values from cache
     """
-    return cache.get(get_cache_key(user, key))
+    return cache.get(get_cache_key(user, key), version=get_cache_version())
 
 
 def set_permission_cache(user, key, value):
@@ -31,7 +40,9 @@ def set_permission_cache(user, key, value):
     """
     # store this key, so we can clean it when required
     cache_key = get_cache_key(user, key)
-    cache.set(cache_key, value, get_cms_setting('CACHE_DURATIONS')['permissions'])
+    cache.set(cache_key, value,
+            get_cms_setting('CACHE_DURATIONS')['permissions'],
+            version=get_cache_version())
 
 
 def clear_user_permission_cache(user):
@@ -39,12 +50,13 @@ def clear_user_permission_cache(user):
     Cleans permission cache for given user.
     """
     for key in PERMISSION_KEYS:
-        cache.delete(get_cache_key(user, key))
+        cache.delete(get_cache_key(user, key), version=get_cache_version())
 
 
 def clear_permission_cache():
-    users = User.objects.filter(is_active=True)
-    for user in users:
-        for key in PERMISSION_KEYS:
-            cache_key = get_cache_key(user, key)
-            cache.delete(cache_key)
+    version = get_cache_version()
+    if version > 1:
+        cache.incr(get_cache_version_key())
+    else:
+        cache.set(get_cache_version_key(), 2,
+                get_cms_setting('CACHE_DURATIONS')['permissions'])
