@@ -11,10 +11,12 @@ class LanguageCookieMiddleware(object):
         if settings.LANGUAGE_COOKIE_NAME in request.COOKIES and \
                 request.COOKIES[settings.LANGUAGE_COOKIE_NAME] == language:
             return response
-        max_age = 365 * 24 * 60 * 60  # 10 years
-        expires = datetime.datetime.now() + datetime.timedelta(seconds=max_age)
-        response.set_cookie(settings.LANGUAGE_COOKIE_NAME, language, expires=expires.utctimetuple(),
-                            max_age=max_age)
+        if not settings.SESSION_EXPIRE_AT_BROWSER_CLOSE:
+            max_age = 365 * 24 * 60 * 60  # 10 years
+            expires = datetime.datetime.now() + datetime.timedelta(seconds=max_age)
+            response.set_cookie(settings.LANGUAGE_COOKIE_NAME, language, expires=expires.utctimetuple(),
+                                max_age=max_age)
+        else:
+            response.set_cookie(settings.LANGUAGE_COOKIE_NAME, language)
         return response
 
-
