@@ -1,19 +1,21 @@
 # -*- coding: utf-8 -*-
 import os
 import warnings
-from datetime import datetime, date
+from datetime import date
 
 from django.conf import settings
 from django.core.exceptions import ValidationError, ObjectDoesNotExist
 from django.db import models
-from django.db.models.base import (model_unpickle, simple_class_factory)
+from django.db.models.base import model_unpickle
 from django.db.models.query_utils import DeferredAttribute
+from django.utils import timezone
 from django.utils.translation import ugettext_lazy as _
 
 from cms.exceptions import DontUsePageAttributeWarning
 from cms.models.placeholdermodel import Placeholder
 from cms.plugin_rendering import PluginContext, render_plugin
 from cms.utils.helpers import reversion_register
+from cms.utils import get_cms_setting
 
 from mptt.models import MPTTModel, MPTTModelBase
 
@@ -81,12 +83,13 @@ class CMSPlugin(MPTTModel):
     position = models.PositiveSmallIntegerField(_("position"), blank=True, null=True, editable=False)
     language = models.CharField(_("language"), max_length=15, blank=False, db_index=True, editable=False)
     plugin_type = models.CharField(_("plugin_name"), max_length=50, db_index=True, editable=False)
-    creation_date = models.DateTimeField(_("creation date"), editable=False, default=datetime.now)
+    creation_date = models.DateTimeField(_("creation date"), editable=False, default=timezone.now)
     changed_date = models.DateTimeField(auto_now=True)
     level = models.PositiveIntegerField(db_index=True, editable=False)
     lft = models.PositiveIntegerField(db_index=True, editable=False)
     rght = models.PositiveIntegerField(db_index=True, editable=False)
     tree_id = models.PositiveIntegerField(db_index=True, editable=False)
+    child_plugin_instances = None
 
     class Meta:
         app_label = 'cms'
@@ -125,7 +128,7 @@ class CMSPlugin(MPTTModel):
                         obj = self.__class__.__dict__[field.attname]
                         model = obj.model_ref()
         else:
-            factory = simple_class_factory
+            factory = lambda x, y: x
         return (model_unpickle, (model, defers, factory), data)
 
     def __unicode__(self):
@@ -151,9 +154,7 @@ class CMSPlugin(MPTTModel):
         if plugin.model != self.__class__: # and self.__class__ == CMSPlugin:
             # (if self is actually a subclass, getattr below would break)
             try:
-                instance = getattr(self, plugin.model.__name__.lower())
-                # could alternatively be achieved with:
-                # instance = plugin_class.model.objects.get(cmsplugin_ptr=self)
+                instance = plugin_class.model.objects.get(cmsplugin_ptr=self)
                 instance._render_meta = self._render_meta
             except (AttributeError, ObjectDoesNotExist):
                 instance = None
@@ -167,7 +168,8 @@ class CMSPlugin(MPTTModel):
             if not isinstance(placeholder, Placeholder):
                 placeholder = instance.placeholder
             placeholder_slot = placeholder.slot
-            context = PluginContext(context, instance, placeholder)
+            current_app = context.current_app if context else None
+            context = PluginContext(context, instance, placeholder, current_app=current_app)
             context = plugin.render(context, instance, placeholder_slot)
             if plugin.render_plugin:
                 template = hasattr(instance, 'render_template') and instance.render_template or plugin.render_template
@@ -175,7 +177,7 @@ class CMSPlugin(MPTTModel):
                     raise ValidationError("plugin has no render_template: %s" % plugin.__class__)
             else:
                 template = None
-            return render_plugin(context, instance, placeholder, template, processors)
+            return render_plugin(context, instance, placeholder, template, processors, context.current_app)
         return ""
 
     def get_media_path(self, filename):
@@ -184,7 +186,7 @@ class CMSPlugin(MPTTModel):
             return pages[0].get_media_path(filename)
         else:  # django 1.0.2 compatibility
             today = date.today()
-            return os.path.join(settings.CMS_PAGE_MEDIA_PATH,
+            return os.path.join(get_cms_setting('PAGE_MEDIA_PATH'),
                 str(today.year), str(today.month), str(today.day), filename)
 
     @property
@@ -225,7 +227,7 @@ class CMSPlugin(MPTTModel):
         for attr in ['parent_id', 'placeholder', 'language', 'plugin_type', 'creation_date', 'level', 'lft', 'rght', 'position', 'tree_id']:
             setattr(plugin, attr, getattr(self, attr))
 
-    def copy_plugin(self, target_placeholder, target_language, plugin_tree):
+    def copy_plugin(self, target_placeholder, target_language, plugin_trail):        
         """
         Copy this plugin and return the new plugin.
         """
@@ -233,21 +235,40 @@ class CMSPlugin(MPTTModel):
             plugin_instance, cls = self.get_plugin_instance()
         except KeyError:  # plugin type not found anymore
             return
+
+        # set up some basic attributes on the new_plugin
         new_plugin = CMSPlugin()
         new_plugin.placeholder = target_placeholder
         new_plugin.tree_id = None
         new_plugin.lft = None
         new_plugin.rght = None
         new_plugin.level = None
-        if self.parent:
-            pdif = self.level - plugin_tree[-1].level
-            if pdif < 0:
-                plugin_tree[:] = plugin_tree[:pdif - 1]
-            new_plugin.parent = plugin_tree[-1]
-            if pdif != 0:
-                plugin_tree.append(new_plugin)
+
+        # In the block below, we use plugin_trail as a kind of breadcrumb trail 
+        # through the tree. 
+        #
+        # we assign a parent to our new plugin
+        if not self.parent:
+            # We're lucky; we don't need to find a parent. We'll just put 
+            # new_plugin into the plugin_trail for potential children to use,
+            # and move on.
+            plugin_trail[:] = [new_plugin]
         else:
-            plugin_tree[:] = [new_plugin]
+            # We will need to find a parent for our new_plugin.
+            marker = plugin_trail.pop()
+            # are we going up or down?
+            level_difference = self.level - marker.level
+            if level_difference == 1: 
+                # going up; put the marker back
+                plugin_trail.append(marker)
+            else:
+                # going down; remove more items from plugin_trail
+                if level_difference < 0:
+                    plugin_trail[:] = plugin_trail[:level_difference]
+            # assign new_plugin.parent 
+            new_plugin.parent = plugin_trail[-1]
+            # new_plugin becomes the last item in the tree for the next round
+            plugin_trail.append(new_plugin)
         new_plugin.level = None
         new_plugin.language = target_language
         new_plugin.plugin_type = self.plugin_type
@@ -267,7 +288,8 @@ class CMSPlugin(MPTTModel):
             plugin_instance.position = new_plugin.position  # added to retain the position when creating a public copy of a plugin
             plugin_instance.save()
             old_instance = plugin_instance.__class__.objects.get(pk=self.pk)
-            plugin_instance.copy_relations(old_instance)
+            plugin_instance.copy_relations(old_instance)   
+
         return new_plugin
 
     def post_copy(self, old_instance, new_old_ziplist):
@@ -320,7 +342,7 @@ class CMSPlugin(MPTTModel):
         """
         WARNING: this is a rather expensive call compared to is_first_in_placeholder!
         """
-        return self.placeholder.cmsplugin_set.all().order_by('-position')[0].pk == self.pk
+        return self.placeholder.cmsplugin_set.filter(parent__isnull=True).order_by('-position')[0].pk == self.pk
 
     def get_position_in_placeholder(self):
         """
@@ -328,6 +350,10 @@ class CMSPlugin(MPTTModel):
         """
         return self.position + 1
 
+    def num_children(self):
+        if self.child_plugin_instances:
+            return len(self.child_plugin_instances)
+
 reversion_register(CMSPlugin)
 
 
