@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 from datetime import datetime
+from cms.utils.conf import get_cms_setting
 from django.db.models import Q
 from django.contrib.sites.models import Site
 from cms.publisher.query import PublisherQuerySet
 from django.conf import settings
 from cms.exceptions import NoHomeFound
-from cms.utils import timezone
-
-#from cms.utils.urlutils import levelize_path
+from django.utils import timezone
 
 
 class PageQuerySet(PublisherQuerySet):
@@ -52,13 +51,13 @@ class PageQuerySet(PublisherQuerySet):
     def published(self, site=None):
         pub = self.on_site(site).filter(published=True)
 
-        if settings.CMS_SHOW_START_DATE:
+        if get_cms_setting('SHOW_START_DATE'):
             pub = pub.filter(
                 Q(publication_date__lt=timezone.now()) |
                 Q(publication_date__isnull=True)
             )
 
-        if settings.CMS_SHOW_END_DATE:
+        if get_cms_setting('SHOW_END_DATE'):
             pub = pub.filter(
                 Q(publication_end_date__gte=timezone.now()) |
                 Q(publication_end_date__isnull=True)
@@ -70,21 +69,6 @@ class PageQuerySet(PublisherQuerySet):
         return self.on_site().filter(
             publication_end_date__lte=timezone.now())
 
-#    - seems this is not used anymore...
-#    def get_pages_with_application(self, path, language):
-#        """Returns all pages containing application for current path, or
-#        any parrent. Returned list is sorted by path length, longer path first.
-#        """
-#        paths = levelize_path(path)
-#        q = Q()
-#        for path in paths:
-#            # build q for all the paths
-#            q |= Q(title_set__path=path, title_set__language=language)
-#        app_pages = self.published().filter(q & Q(title_set__application_urls__gt='')).distinct()
-#        # add proper ordering
-#        app_pages.query.order_by.extend(('LENGTH(`cms_title`.`path`) DESC',))
-#        return app_pages
-
     def get_all_pages_with_application(self):
         """Returns all pages containing applications for all sites.
 
@@ -94,7 +78,7 @@ class PageQuerySet(PublisherQuerySet):
 
     def get_home(self, site=None):
         try:
-            home = self.on_site(site).filter(published=True).all_root().order_by("tree_id")[0]
+            home = self.published(site).all_root().order_by("tree_id")[0]
         except IndexError:
             raise NoHomeFound('No Root page found. Publish at least one page!')
         return home
