@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 from django.db import models
+from django.utils import timezone
 from django.utils.translation import ugettext_lazy as _
 from cms.models.managers import TitleManager
 from cms.models.pagemodel import Page
 from cms.utils.helpers import reversion_register
-from cms.utils import timezone
 
 
 class Title(models.Model):
@@ -29,29 +29,24 @@ class Title(models.Model):
         app_label = 'cms'
 
     def __unicode__(self):
-        return "%s (%s)" % (self.title, self.slug)
-
-    def save(self, *args, **kwargs):
-        # Update the path attribute before saving
-        self.update_path()
-        super(Title, self).save(*args, **kwargs)
+        return u"%s (%s, %s)" % (self.title, self.slug, self.language)
 
     def update_path(self):
         # Build path from parent page's path and slug
-        current_path = self.path
-        parent_page = self.page.parent
-
         slug = u'%s' % self.slug
         if not self.has_url_overwrite:
             self.path = u'%s' % slug
-            if parent_page:
+            if self.page.parent_id:
+                parent_page = self.page.parent_id
+
                 parent_title = Title.objects.get_title(parent_page, language=self.language, language_fallback=True)
                 if parent_title:
                     self.path = u'%s/%s' % (parent_title.path, slug)
+        
 
     @property
     def overwrite_url(self):
-        """Return overrwriten url, or None
+        """Return overwritten url, or None
         """
         if self.has_url_overwrite:
             return self.path
