@@ -8,7 +8,7 @@ class Link(CMSPlugin):
     """
 
     name = models.CharField(_("name"), max_length=256)
-    url = models.URLField(_("link"), verify_exists=False, blank=True, null=True)
+    url = models.URLField(_("link"), blank=True, null=True)
     page_link = models.ForeignKey(Page, verbose_name=_("page"), blank=True, null=True, help_text=_("A link to a page has priority over a text link."))
     mailto = models.EmailField(_("mailto"), blank=True, null=True, help_text=_("An email adress has priority over a text link."))
     target = models.CharField(_("target"), blank=True, max_length=100, choices=((
@@ -17,7 +17,7 @@ class Link(CMSPlugin):
         ("_parent", _("parent window")),
         ("_top", _("topmost frame")),
     )))
-    
+
     def __unicode__(self):
         return self.name
 
