@@ -1,7 +1,10 @@
-from cms.models import CMSPlugin
-from django.template.defaultfilters import force_escape
 import re
 
+from django.template.defaultfilters import force_escape
+
+from cms.models import CMSPlugin
+from cms.plugins.utils import downcast_plugins
+
 OBJ_TAG_RE = re.compile(u"\{\{ plugin_object (\d+) \}\}")
 OBJ_ADMIN_RE_PATTERN = ur'<img [^>]*\bid="plugin_obj_(\d+)"[^>]*/?>'
 OBJ_ADMIN_RE = re.compile(OBJ_ADMIN_RE_PATTERN)
@@ -11,11 +14,12 @@ def plugin_tags_to_admin_html(text):
     Convert plugin object 'tags' into the form used to represent
     them in the admin text editor.
     """
+    plugin_map = _plugin_dict(text, regex=OBJ_TAG_RE)
     def _tag_to_admin(m):
         plugin_id = int(m.groups()[0])
         try:
-            obj = CMSPlugin.objects.get(pk=plugin_id)
-        except CMSPlugin.DoesNotExist:
+            obj = plugin_map[plugin_id]
+        except KeyError:
             # Object must have been deleted.  It cannot be rendered to
             # end user, or edited, so just remove it from the HTML
             # altogether
@@ -28,9 +32,9 @@ def plugin_tags_to_admin_html(text):
     return OBJ_TAG_RE.sub(_tag_to_admin, text)
 
 
-def plugin_tags_to_id_list(text):
-    ls = OBJ_ADMIN_RE.findall(text)    
-    return ls
+def plugin_tags_to_id_list(text, regex=OBJ_ADMIN_RE):
+    ids = regex.findall(text)
+    return [int(id) for id in ids if id.isdigit()]
 
 def plugin_tags_to_user_html(text, context, placeholder):
     """
@@ -38,12 +42,13 @@ def plugin_tags_to_user_html(text, context, placeholder):
 
     context is the template context to use, placeholder is the placeholder name
     """
+    plugin_map = _plugin_dict(text)
     def _render_tag(m):
         plugin_id = int(m.groups()[0])
         try:
-            obj = CMSPlugin.objects.get(pk=plugin_id)
+            obj = plugin_map[plugin_id]
             obj._render_meta.text_enabled = True
-        except CMSPlugin.DoesNotExist:
+        except KeyError:
             # Object must have been deleted.  It cannot be rendered to
             # end user so just remove it from the HTML altogether
             return u''
@@ -75,3 +80,9 @@ def replace_plugin_tags(text, id_dict):
                     icon_alt=force_escape(obj.get_instance_icon_alt()),
                     )
     return OBJ_ADMIN_RE.sub(_replace_tag, text)
+
+
+def _plugin_dict(text, regex=OBJ_ADMIN_RE):
+    plugin_ids = plugin_tags_to_id_list(text, regex)
+    plugin_list = downcast_plugins(CMSPlugin.objects.filter(pk__in=plugin_ids), select_placeholder=True)
+    return dict((plugin.pk, plugin) for plugin in plugin_list)
\ No newline at end of file
