@@ -12,13 +12,15 @@ class RenderPlaceholder(Tag):
     options = Options(
         Argument('placeholder'),
         Argument('width', default=None, required=False),
+        'language',
+        Argument('language', default=None, required=False),
     )
 
-    def render_tag(self, context, placeholder, width):
+    def render_tag(self, context, placeholder, width, language=None):
         request = context.get('request', None)
         if not request:
             return ''
         if not placeholder:
             return ''
-        return safe(placeholder.render(context, width))
+        return safe(placeholder.render(context, width, lang=language))
 register.tag(RenderPlaceholder)
\ No newline at end of file
