@@ -1,3 +1,4 @@
+from cms.utils.conf import get_cms_setting
 from django.conf import settings
 from django.conf.urls.defaults import handler500, handler404, patterns, include, \
     url
@@ -6,7 +7,7 @@ from django.conf.urls.defaults import handler500, handler404, patterns, include,
 urlpatterns = patterns('',
     url(r'^jsi18n/(?P<packages>\S+?)/$', 'django.views.i18n.javascript_catalog'),
     url(r'^media/cms/(?P<path>.*)$', 'django.views.static.serve',
-        {'document_root': settings.CMS_MEDIA_ROOT, 'show_indexes': True}),
+        {'document_root': get_cms_setting('MEDIA_ROOT'), 'show_indexes': True}),
     url(r'^media/(?P<path>.*)$', 'django.views.static.serve',
         {'document_root': settings.MEDIA_ROOT, 'show_indexes': True}),
     url(r'^', include('cms.urls')),
