@@ -1,5 +1,7 @@
 from django.db import models
 from cms.models.fields import PlaceholderField
+from hvad.models import TranslatableModel, TranslatedFields
+
 
 class Example1(models.Model):
     char_1 = models.CharField(u'char_1', max_length=255)
@@ -8,6 +10,7 @@ class Example1(models.Model):
     char_4 = models.CharField(u'char_4', max_length=255)
     placeholder = PlaceholderField('placeholder')
 
+
 class Example2(models.Model):
     char_1 = models.CharField(u'char_1', max_length=255)
     char_2 = models.CharField(u'char_2', max_length=255)
@@ -15,6 +18,7 @@ class Example2(models.Model):
     char_4 = models.CharField(u'char_4', max_length=255)
     placeholder = PlaceholderField('placeholder')
 
+
 class Example3(models.Model):
     char_1 = models.CharField(u'char_1', max_length=255)
     char_2 = models.CharField(u'char_2', max_length=255)
@@ -22,6 +26,7 @@ class Example3(models.Model):
     char_4 = models.CharField(u'char_4', max_length=255)
     placeholder = PlaceholderField('placeholder')
 
+
 class Example4(models.Model):
     char_1 = models.CharField(u'char_1', max_length=255)
     char_2 = models.CharField(u'char_2', max_length=255)
@@ -29,6 +34,7 @@ class Example4(models.Model):
     char_4 = models.CharField(u'char_4', max_length=255)
     placeholder = PlaceholderField('placeholder')
 
+
 class Example5(models.Model):
     char_1 = models.CharField(u'char_1', max_length=255)
     char_2 = models.CharField(u'char_2', max_length=255)
@@ -36,3 +42,14 @@ class Example5(models.Model):
     char_4 = models.CharField(u'char_4', max_length=255)
     placeholder_1 = PlaceholderField('placeholder_1', related_name='p1')
     placeholder_2 = PlaceholderField('placeholder_2', related_name='p2')
+
+
+class MultilingualExample1(TranslatableModel):
+    translations = TranslatedFields(
+        char_1=models.CharField(u'char_1', max_length=255),
+        char_2=models.CharField(u'char_2', max_length=255),
+    )
+    placeholder_1 = PlaceholderField('placeholder_1')
+
+    def __unicode__(self):
+        return self.char_1
\ No newline at end of file
