@@ -187,6 +187,28 @@ class ApphooksTestCase(CMSTestCase):
 
             apphook_pool.clear()
 
+    def test_get_page_for_apphook_on_preview_or_edit(self):
+        superuser = User.objects.create_superuser('admin', 'admin@admin.com', 'admin')
+        page = create_page("home", "nav_playground.html", "en",
+                            created_by=superuser, published=True, apphook=APP_NAME)
+        create_title('de', page.get_title(), page, apphook=APP_NAME)
+        page.publish()
+        public_page = page.get_public_object()
+
+        with self.login_user_context(superuser):
+            with force_language("en"):
+                path = reverse('sample-settings')
+                request = self.get_request(path + '?edit')
+                request.LANGUAGE_CODE = 'en'
+                attached_to_page = applications_page_check(request, path=path[1:]) # strip leading slash
+                self.assertEquals(attached_to_page.pk, public_page.pk)
+            with force_language("de"):
+                path = reverse('sample-settings')
+                request = self.get_request(path + '?edit')
+                request.LANGUAGE_CODE = 'de'
+                attached_to_page = applications_page_check(request, path=path[1:]) # strip leading slash
+                self.assertEquals(attached_to_page.pk, public_page.pk)
+
     def test_get_root_page_for_apphook_with_instance_namespace(self):
         with SettingsOverride(ROOT_URLCONF='cms.test_utils.project.second_urls_for_apphook_tests'):
             en_title = self.create_base_structure(NS_APP_NAME, 'en', 'instance_ns')
