@@ -15,6 +15,7 @@ from django.utils import timezone
 from cms.admin.forms import PageForm
 from cms.admin.pageadmin import PageAdmin
 from cms.api import create_page, add_plugin
+from cms.middleware.user import CurrentUserMiddleware
 from cms.models import Page, Title
 from cms.models.placeholdermodel import Placeholder
 from cms.models.pluginmodel import CMSPlugin
@@ -816,6 +817,22 @@ class PageAdminTestBase(CMSTestCase):
 
 
 class PageAdminTest(PageAdminTestBase):
+    def test_form_url_page_change(self):
+        superuser = self.get_superuser()
+        with self.login_user_context(superuser):
+            pageadmin = self.get_admin()
+            page = self.get_page()
+            form_url = reverse("admin:cms_page_change", args=(1,))
+            # Middleware is needed to correctly setup the environment for the admin
+            middleware = CurrentUserMiddleware()
+            request = self.get_request()
+            middleware.process_request(request)
+            response = pageadmin.change_view(
+                request, str(page.pk),
+                form_url=form_url)
+            self.assertTrue('form_url' in response.context_data)
+            self.assertEquals(response.context_data['form_url'], form_url)
+
     def test_global_limit_on_plugin_move(self):
         admin = self.get_admin()
         superuser = self.get_superuser()
