@@ -1,15 +1,20 @@
 # -*- coding: utf-8 -*-
+from __future__ import with_statement
+import urllib
+
 from classytags.arguments import IntegerArgument, Argument, StringArgument
 from classytags.core import Options
 from classytags.helpers import InclusionTag
+from cms.utils.i18n import force_language, get_language_objects
 from django import template
 from django.conf import settings
 from django.contrib.sites.models import Site
 from django.core.cache import cache
-from django.core.urlresolvers import reverse
+from django.core.urlresolvers import reverse, resolve
 from django.utils.translation import activate, get_language, ugettext
 from menus.menu_pool import menu_pool
-import urllib
+from menus.utils import DefaultLanguageChanger
+
 
 register = template.Library()
 
@@ -35,12 +40,14 @@ def cut_after(node, levels, removed):
             node.children.remove(removed_child)
         removed.extend(removed_local)
 
+
 def remove(node, removed):
     removed.append(node)
     if node.parent:
         if node in node.parent.children:
             node.parent.children.remove(node)
 
+
 def cut_levels(nodes, from_level, to_level, extra_inactive, extra_active):
     """
     cutting nodes away from menus
@@ -48,7 +55,7 @@ def cut_levels(nodes, from_level, to_level, extra_inactive, extra_active):
     final = []
     removed = []
     selected = None
-    for node in nodes: 
+    for node in nodes:
         if not hasattr(node, 'level'):
             # remove and ignore nodes that don't have level information
             remove(node, removed)
@@ -77,6 +84,7 @@ def cut_levels(nodes, from_level, to_level, extra_inactive, extra_active):
                 final.remove(node)
     return final
 
+
 def flatten(nodes):
     flat = []
     for node in nodes:
@@ -98,7 +106,7 @@ class ShowMenu(InclusionTag):
     """
     name = 'show_menu'
     template = 'menu/dummy.html'
-    
+
     options = Options(
         IntegerArgument('from_level', default=0, required=False),
         IntegerArgument('to_level', default=100, required=False),
@@ -109,7 +117,7 @@ class ShowMenu(InclusionTag):
         StringArgument('root_id', default=None, required=False),
         Argument('next_page', default=None, required=False),
     )
-    
+
     def get_context(self, context, from_level, to_level, extra_inactive,
                     extra_active, template, namespace, root_id, next_page):
         try:
@@ -117,11 +125,11 @@ class ShowMenu(InclusionTag):
             request = context['request']
         except KeyError:
             return {'template': 'menu/empty.html'}
-        
+
         if next_page:
             children = next_page.children
-        else: 
-            #new menu... get all the data so we can save a lot of queries
+        else:
+        #new menu... get all the data so we can save a lot of queries
             nodes = menu_pool.get_nodes(request, namespace, root_id)
             if root_id: # find the root id and cut the nodes
                 id_nodes = menu_pool.get_nodes_by_attribute(nodes, "reverse_id", root_id)
@@ -137,18 +145,20 @@ class ShowMenu(InclusionTag):
                     nodes = []
             children = cut_levels(nodes, from_level, to_level, extra_inactive, extra_active)
             children = menu_pool.apply_modifiers(children, request, namespace, root_id, post_cut=True)
-    
+
         try:
-            context.update({'children':children,
-                            'template':template,
-                            'from_level':from_level,
-                            'to_level':to_level,
-                            'extra_inactive':extra_inactive,
-                            'extra_active':extra_active,
-                            'namespace':namespace})
+            context.update({'children': children,
+                'template': template,
+                'from_level': from_level,
+                'to_level': to_level,
+                'extra_inactive': extra_inactive,
+                'extra_active': extra_active,
+                'namespace': namespace})
         except:
-            context = {"template":template}
+            context = {"template": template}
         return context
+
+
 register.tag(ShowMenu)
 
 
@@ -164,6 +174,8 @@ class ShowMenuBelowId(ShowMenu):
         Argument('namespace', default=None, required=False),
         Argument('next_page', default=None, required=False),
     )
+
+
 register.tag(ShowMenuBelowId)
 
 
@@ -171,17 +183,21 @@ class ShowSubMenu(InclusionTag):
     """
     show the sub menu of the current nav-node.
     - levels: how many levels deep
+    - root_level: the level to start the menu at
+    - nephews: the level of descendants of siblings (nephews) to show
     - template: template used to render the navigation
     """
     name = 'show_sub_menu'
     template = 'menu/dummy.html'
-    
+
     options = Options(
         IntegerArgument('levels', default=100, required=False),
+        IntegerArgument('root_level', default=None, required=False),
+        IntegerArgument('nephews', default=100, required=False),
         Argument('template', default='menu/sub_menu.html', required=False),
     )
-    
-    def get_context(self, context, levels, template):
+
+    def get_context(self, context, levels, root_level, nephews, template):
         try:
             # If there's an exception (500), default context_processors may not be called.
             request = context['request']
@@ -189,22 +205,45 @@ class ShowSubMenu(InclusionTag):
             return {'template': 'menu/empty.html'}
         nodes = menu_pool.get_nodes(request)
         children = []
+        # adjust root_level so we cut before the specified level, not after
+        include_root = False
+        if root_level > 0:
+            root_level -= 1
+        elif root_level == 0:
+            include_root = True
         for node in nodes:
-            if node.selected:
+            if root_level is None:
+                if node.selected:
+                    # if no root_level specified, set it to the selected nodes level
+                    root_level = node.level
+                # is this the ancestor of current selected node at the root level?
+            is_root_ancestor = (node.ancestor and node.level == root_level)
+            # is a node selected on the root_level specified
+            root_selected = (node.selected and node.level == root_level)
+            if is_root_ancestor or root_selected:
                 cut_after(node, levels, [])
                 children = node.children
                 for child in children:
                     child.parent = None
-                children = menu_pool.apply_modifiers(children, request, post_cut=True)
+                    if child.sibling:
+                        cut_after(child, nephews, [])
+                    # if root_level was 0 we need to give the menu the entire tree
+                # not just the children
+                if include_root:
+                    children = menu_pool.apply_modifiers([node], request, post_cut=True)
+                else:
+                    children = menu_pool.apply_modifiers(children, request, post_cut=True)
         context.update({
-            'children':children,
-            'template':template,
-            'from_level':0,
-            'to_level':0,
-            'extra_inactive':0,
-            'extra_active':0
+            'children': children,
+            'template': template,
+            'from_level': 0,
+            'to_level': 0,
+            'extra_inactive': 0,
+            'extra_active': 0
         })
-        return context        
+        return context
+
+
 register.tag(ShowSubMenu)
 
 
@@ -217,7 +256,7 @@ class ShowBreadcrumb(InclusionTag):
     """
     name = 'show_breadcrumb'
     template = 'menu/dummy.html'
-    
+
     options = Options(
         Argument('start_level', default=0, required=False),
         Argument('template', default='menu/breadcrumb.html', required=False),
@@ -260,25 +299,31 @@ class ShowBreadcrumb(InclusionTag):
             ancestors = ancestors[start_level:]
         else:
             ancestors = []
-        context.update({'ancestors':ancestors,
-                        'template': template})
+        context.update({'ancestors': ancestors,
+            'template': template})
         return context
+
+
 register.tag(ShowBreadcrumb)
 
 
 def _raw_language_marker(language, lang_code):
     return language
 
+
 def _native_language_marker(language, lang_code):
-    activate(lang_code)
-    return unicode(ugettext(language))
+    with force_language(lang_code):
+        return unicode(ugettext(language))
+
 
 def _current_language_marker(language, lang_code):
     return unicode(ugettext(language))
 
+
 def _short_language_marker(language, lang_code):
     return lang_code
 
+
 MARKERS = {
     'raw': _raw_language_marker,
     'native': _native_language_marker,
@@ -286,6 +331,7 @@ MARKERS = {
     'short': _short_language_marker,
 }
 
+
 class LanguageChooser(InclusionTag):
     """
     Displays a language chooser
@@ -293,7 +339,7 @@ class LanguageChooser(InclusionTag):
     """
     name = 'language_chooser'
     template = 'menu/dummy.html'
-    
+
     options = Options(
         Argument('template', default=NOT_PROVIDED, required=False),
         Argument('i18n_mode', default='raw', required=False),
@@ -315,26 +361,21 @@ class LanguageChooser(InclusionTag):
             # If there's an exception (500), default context_processors may not be called.
             return {'template': 'cms/content.html'}
         marker = MARKERS[i18n_mode]
-        cms_languages = dict(settings.CMS_LANGUAGES)
         current_lang = get_language()
         site = Site.objects.get_current()
-        site_languages = settings.CMS_SITE_LANGUAGES.get(site.pk, cms_languages.keys())
-        cache_key = '%s-language-chooser-%s-%s-%s' % (settings.CMS_CACHE_PREFIX, site.pk, current_lang, i18n_mode)
-        languages = cache.get(cache_key, [])
-        if not languages:
-            for lang in settings.CMS_FRONTEND_LANGUAGES:
-                if lang in cms_languages and lang in site_languages:
-                    languages.append((lang, marker(cms_languages[lang], lang)))
-            if current_lang != get_language():
-                activate(current_lang)
-            cache.set(cache_key, languages)
-        lang = get_language()
+        user_is_staff = context['request'].user.is_staff
+        languages = []
+        for lang in get_language_objects(site.pk):
+            if user_is_staff or lang.get('public', True):
+                languages.append((lang['code'], marker(lang['name'], lang['code'])))
         context.update({
-            'languages':languages,
-            'current_language':lang,
-            'template':template,
+            'languages': languages,
+            'current_language': current_lang,
+            'template': template,
         })
         return context
+
+
 register.tag(LanguageChooser)
 
 
@@ -346,11 +387,11 @@ class PageLanguageUrl(InclusionTag):
     """
     name = 'page_language_url'
     template = 'cms/content.html'
-    
+
     options = Options(
         Argument('lang'),
     )
-    
+
     def get_context(self, context, lang):
         try:
             # If there's an exception (500), default context_processors may not be called.
@@ -358,26 +399,11 @@ class PageLanguageUrl(InclusionTag):
         except KeyError:
             return {'template': 'cms/content.html'}
         if hasattr(request, "_language_changer"):
-            try:
-                setattr(request._language_changer, 'request', request)
-            except AttributeError:
-                pass
-            url = "/%s" % lang + request._language_changer(lang)
+            url = request._language_changer(lang)
         else:
-            page = request.current_page
-            if page == "dummy":
-                return {'content': ''}
-            try:
-                url = page.get_absolute_url(language=lang, fallback=False)
-                url = "/" + lang + url
-            except:
-                # no localized path/slug
-                if settings.CMS_HIDE_UNTRANSLATED:
-                    # redirect to root url if CMS_HIDE_UNTRANSLATED
-                    url = '/' + lang + '/'
-                else:
-                    # If untranslated pages are shown, this will not redirect
-                    # at all.
-                    url = ''
-        return {'content':url}
+            # use the default language changer
+            url = DefaultLanguageChanger(request)(lang)
+        return {'content': url}
+
+
 register.tag(PageLanguageUrl)
