@@ -78,7 +78,10 @@ class DefaultLanguageChanger(object):
     @property
     def app_path(self):
         if self._app_path is None:
-            page_path = self.get_page_path(self.request.LANGUAGE_CODE)
+            if settings.USE_I18N:
+                page_path = self.get_page_path(self.request.LANGUAGE_CODE)
+            else:
+                page_path = self.get_page_path(settings.LANGUAGE_CODE)
             if page_path:
                 self._app_path = self.request.path[len(page_path):]
             else:
@@ -95,12 +98,15 @@ class DefaultLanguageChanger(object):
                 try:
                     return page.get_absolute_url(language=lang, fallback=False)
                 except Title.DoesNotExist:
-                    if hide_untranslated(lang):
+                    if hide_untranslated(lang) and settings.USE_I18N:
                         return '/%s/' % lang
                     else:
                         return page.get_absolute_url(language=lang, fallback=True)
         else:
-            return '/%s/' % lang
+            if settings.USE_I18N:
+                return '/%s/' % lang
+            else:
+                return "/"
 
 def simple_language_changer(func):
     warnings.warn("simple_language_changer is deprecated and will be removed in "
